@@ -158,8 +158,14 @@ def requires(binary_tag):
     Return the minimum required platform for a binary_tag.
     '''
     arch, os_id, comp = binary_tag.split('-')[:3]
-    if comp.startswith('gcc') and comp >= 'gcc6' and arch.startswith('x86_64'):
-        arch += '+sse4_2'
+    if comp.startswith(('gcc', 'clang')) and arch.startswith('x86_64'):
+        comp_version = comp.strip('gcc').strip('clang').split("+", 1)[0]
+        # Between gcc 3.4 and gcc 6.2, two digits were used for the version
+        # Append "0" to all other versions to make the subsequent comparison work
+        if not (3 <= int(comp_version[0]) <= 6):
+            comp_version += "0"
+        if int(comp_version) >= 60:
+            arch += '+sse4_2'
     arch = _promote_old_style_arch(arch)
     return '-'.join([arch, os_id])
 
